@@ -1,4 +1,26 @@
 operation_parameter_map = {
+    '/accounts/{accountId}/activities-GET': {
+        'parameters': [
+            {
+                'name': 'accountId'
+            },
+            {
+                'name': 'userId'
+            },
+            {
+                'name': 'userSecret'
+            },
+            {
+                'name': 'startDate'
+            },
+            {
+                'name': 'endDate'
+            },
+            {
+                'name': 'type'
+            },
+        ]
+    },
     '/holdings-GET': {
         'parameters': [
             {
@@ -553,6 +575,15 @@ operation_parameter_map = {
             {
                 'name': 'notional_value'
             },
+            {
+                'name': 'order_class'
+            },
+            {
+                'name': 'stop_loss'
+            },
+            {
+                'name': 'take_profit'
+            },
         ]
     },
     '/trade/{tradeId}-POST': {
